@@ -20,7 +20,7 @@ use SDL::App::FPS::Demo;
 my $options = { width => 640, height => 480, max_fps => 40};
 
 print
-  "SDL::App::FPS Demo v0.01 (C) 2002,2003 by Tels <http://Bloodgate.com/>\n\n";
+  "SDL::App::FPS Demo v0.02 (C) 2002,2003 by Tels <http://Bloodgate.com/>\n\n";
 
 my $app = SDL::App::FPS::Demo->new( $options );
 $app->main_loop();
@@ -31,5 +31,5 @@ print "Minimum framerate ",int($app->min_fps()*10)/10,
 print "Minimum time per frame ", $app->min_frame_time(),
       " ms, maximum time per frame ", $app->max_frame_time()," ms\n";
 print "Maximum number of rectangles: ",
-       scalar @{$app->{demo}->{rectangles}},"\n\n";
+       scalar @{$app->{rectangles}},"\n\n";
 print "Thank you for playing!\n";
