@@ -33,6 +33,8 @@ $VERSION = '0.02';
   BUTTON_MOUSE_LEFT
   BUTTON_MOUSE_RIGHT
   BUTTON_MOUSE_MIDDLE
+  BUTTON_MOUSE_WHEEL_UP
+  BUTTON_MOUSE_WHEEL_DOWN
   /;
 
 sub BUTTON_IN () 	{ 1; }
@@ -47,9 +49,11 @@ sub BUTTON_CLICK ()	{ 32; }
 sub BUTTON_RECTANGULAR ()	{ 0; }
 sub BUTTON_ELLIPTIC ()		{ 1; }
 
-sub BUTTON_MOUSE_LEFT ()	{ 1; }
-sub BUTTON_MOUSE_RIGHT ()	{ 4; }
-sub BUTTON_MOUSE_MIDDLE ()	{ 2; }
+sub BUTTON_MOUSE_LEFT ()	{  1; }
+sub BUTTON_MOUSE_RIGHT ()	{  4; }
+sub BUTTON_MOUSE_MIDDLE ()	{  2; }
+sub BUTTON_MOUSE_WHEEL_UP ()    {  8; }
+sub BUTTON_MOUSE_WHEEL_DOWN ()  { 16; }
 
 sub _init
   {
@@ -352,6 +356,9 @@ Mouse button types:
   BUTTON_MOUSE_LEFT
   BUTTON_MOUSE_RIGHT
   BUTTON_MOUSE_MIDDLE
+  BUTTON_MOUSE_WHEEL_DOWN
+  BUTTON_MOUSE_WHEEL_UP
+  BUTTON_MOUSE_MIDDLE
 
 =head1 DESCRIPTION
 
